.wp-block-social-links {

	// Social icons are horizontal, so they don't need vertical spacing.
	[data-block] {
		margin-top: 0;
		margin-bottom: 0;
	}

	&.is-style-twentytwentyone-social-icons-color {

		button {
			color: var(--global--color-primary);
		}

		.wp-social-link {
			background: none;
		}
	}

}
